@@ -27,8 +27,6 @@
 #include "daemon.h"
 #include "actions.h"
 
-GUESTFSD_EXT_CMD(str_dd, dd);
-
 int
 do_dd (const char *src, const char *dest)
 {
@@ -37,7 +35,7 @@ do_dd (const char *src, const char *dest)
   CLEANUP_FREE char *err = NULL;
   int r;
 
-  src_is_dev = STRPREFIX (src, "/dev/");
+  src_is_dev = is_device_parameter (src);
 
   if (src_is_dev)
     r = asprintf (&if_arg, "if=%s", src);
@@ -48,7 +46,7 @@ do_dd (const char *src, const char *dest)
     return -1;
   }
 
-  dest_is_dev = STRPREFIX (dest, "/dev/");
+  dest_is_dev = is_device_parameter (dest);
 
   if (dest_is_dev)
     r = asprintf (&of_arg, "of=%s", dest);
@@ -59,7 +57,7 @@ do_dd (const char *src, const char *dest)
     return -1;
   }
 
-  r = command (NULL, &err, str_dd, "bs=1024K", if_arg, of_arg, NULL);
+  r = command (NULL, &err, "dd", "bs=1024K", if_arg, of_arg, NULL);
   if (r == -1) {
     reply_with_error ("%s: %s: %s", src, dest, err);
     return -1;
@@ -73,7 +71,7 @@ do_copy_size (const char *src, const char *dest, int64_t ssize)
 {
   int src_fd, dest_fd;
 
-  if (STRPREFIX (src, "/dev/"))
+  if (is_device_parameter (src))
     src_fd = open (src, O_RDONLY | O_CLOEXEC);
   else {
     CLEANUP_FREE char *buf = sysroot_path (src);
@@ -88,7 +86,7 @@ do_copy_size (const char *src, const char *dest, int64_t ssize)
     return -1;
   }
 
-  if (STRPREFIX (dest, "/dev/"))
+  if (is_device_parameter (dest))
     dest_fd = open (dest, O_WRONLY | O_CLOEXEC);
   else {
     CLEANUP_FREE char *buf = sysroot_path (dest);
