@@ -32,16 +32,10 @@
 
 #define MAX_ARGS 64
 
-GUESTFSD_EXT_CMD(str_mkfs_xfs, mkfs.xfs);
-GUESTFSD_EXT_CMD(str_xfs_admin, xfs_admin);
-GUESTFSD_EXT_CMD(str_xfs_info, xfs_info);
-GUESTFSD_EXT_CMD(str_xfs_growfs, xfs_growfs);
-GUESTFSD_EXT_CMD(str_xfs_repair, xfs_repair);
-
 int
 optgroup_xfs_available (void)
 {
-  return prog_exists (str_mkfs_xfs);
+  return prog_exists ("mkfs.xfs");
 }
 
 /* Return everything up to the first comma, equals or space in the input
@@ -68,7 +62,7 @@ parse_uint32 (uint32_t *ret, const char *str)
   uint32_t r;
 
   if (sscanf (str, "%" SCNu32, &r) != 1) {
-    reply_with_error ("cannot parse numeric field from isoinfo: %s", str);
+    reply_with_error ("cannot parse numeric field from xfs_info: %s", str);
     return -1;
   }
 
@@ -82,7 +76,7 @@ parse_uint64 (uint64_t *ret, const char *str)
   uint64_t r;
 
   if (sscanf (str, "%" SCNu64, &r) != 1) {
-    reply_with_error ("cannot parse numeric field from isoinfo: %s", str);
+    reply_with_error ("cannot parse numeric field from xfs_info: %s", str);
     return -1;
   }
 
@@ -333,7 +327,7 @@ do_xfs_info (const char *pathordevice)
   CLEANUP_FREE_STRING_LIST char **lines = NULL;
   int is_dev;
 
-  is_dev = STREQLEN (pathordevice, "/dev/", 5);
+  is_dev = is_device_parameter (pathordevice);
   buf = is_dev ? strdup (pathordevice)
                : sysroot_path (pathordevice);
   if (buf == NULL) {
@@ -341,7 +335,7 @@ do_xfs_info (const char *pathordevice)
     return NULL;
   }
 
-  r = command (&out, &err, str_xfs_info, buf, NULL);
+  r = command (&out, &err, "xfs_info", buf, NULL);
   if (r == -1) {
     reply_with_error ("%s", err);
     return NULL;
@@ -376,7 +370,7 @@ do_xfs_growfs (const char *path,
     return -1;
   }
 
-  ADD_ARG (argv, i, str_xfs_growfs);
+  ADD_ARG (argv, i, "xfs_growfs");
 
   /* Optional arguments */
   if (!(optargs_bitmask & GUESTFS_XFS_GROWFS_DATASEC_BITMASK))
@@ -487,7 +481,7 @@ do_xfs_admin (const char *device,
   const char *argv[MAX_ARGS];
   size_t i = 0;
 
-  ADD_ARG (argv, i, str_xfs_admin);
+  ADD_ARG (argv, i, "xfs_admin");
 
   /* Optional arguments */
   if (!(optargs_bitmask & GUESTFS_XFS_ADMIN_EXTUNWRITTEN_BITMASK))
@@ -564,7 +558,7 @@ do_xfs_repair (const char *device,
   size_t i = 0;
   int is_device;
 
-  ADD_ARG (argv, i, str_xfs_repair);
+  ADD_ARG (argv, i, "xfs_repair");
 
   /* Optional arguments */
   if (optargs_bitmask & GUESTFS_XFS_REPAIR_FORCELOGZERO_BITMASK) {
@@ -637,7 +631,7 @@ do_xfs_repair (const char *device,
     ADD_ARG (argv, i, rtdev);
   }
 
-  is_device = STREQLEN (device, "/dev/", 5);
+  is_device = is_device_parameter (device);
   if (!is_device) {
     buf = sysroot_path (device);
     if (buf == NULL) {
