@@ -18,9 +18,10 @@
 
 # Test guestfish file attributes commands (chmod, copy-attributes, etc).
 
+source ../tests/functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 rm -f test-file-attrs.out
