@@ -19,9 +19,10 @@
 # Test passing invalid parameters for memory size, smp, etc when setting up
 # the appliance.
 
+source ../tests/functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 # Memory size
