@@ -18,7 +18,11 @@
 
 # Test remote events in guestfish.
 
+source ../tests/functions.sh
 set -e
+set -x
+
+skip_if_skipped
 
 eval "$(guestfish --listen)"
 
