@@ -194,37 +194,6 @@ create_drive_curl (guestfs_h *g,
   return create_drive_non_file (g, data);
 }
 
-static struct drive *
-create_drive_gluster (guestfs_h *g,
-                      const struct drive_create_data *data)
-{
-  if (data->username != NULL) {
-    error (g, _("gluster: you cannot specify a username with this protocol"));
-    return NULL;
-  }
-  if (data->secret != NULL) {
-    error (g, _("gluster: you cannot specify a secret with this protocol"));
-    return NULL;
-  }
-
-  if (data->nr_servers != 1) {
-    error (g, _("gluster: you must specify exactly one server"));
-    return NULL;
-  }
-
-  if (STREQ (data->exportname, "")) {
-    error (g, _("gluster: volume name parameter should not be an empty string"));
-    return NULL;
-  }
-
-  if (data->exportname[0] == '/') {
-    error (g, _("gluster: volume/image must not begin with a '/'"));
-    return NULL;
-  }
-
-  return create_drive_non_file (g, data);
-}
-
 static int
 nbd_port (void)
 {
@@ -292,46 +261,6 @@ create_drive_rbd (guestfs_h *g,
   return create_drive_non_file (g, data);
 }
 
-static struct drive *
-create_drive_sheepdog (guestfs_h *g,
-                       const struct drive_create_data *data)
-{
-  size_t i;
-
-  if (data->username != NULL) {
-    error (g, _("sheepdog: you cannot specify a username with this protocol"));
-    return NULL;
-  }
-  if (data->secret != NULL) {
-    error (g, _("sheepdog: you cannot specify a secret with this protocol"));
-    return NULL;
-  }
-
-  for (i = 0; i < data->nr_servers; ++i) {
-    if (data->servers[i].transport != drive_transport_none &&
-        data->servers[i].transport != drive_transport_tcp) {
-      error (g, _("sheepdog: only tcp transport is supported"));
-      return NULL;
-    }
-    if (data->servers[i].port == 0) {
-      error (g, _("sheepdog: port number must be specified"));
-      return NULL;
-    }
-  }
-
-  if (STREQ (data->exportname, "")) {
-    error (g, _("sheepdog: volume parameter should not be an empty string"));
-    return NULL;
-  }
-
-  if (data->exportname[0] == '/') {
-    error (g, _("sheepdog: volume parameter must not begin with a '/'"));
-    return NULL;
-  }
-
-  return create_drive_non_file (g, data);
-}
-
 static struct drive *
 create_drive_ssh (guestfs_h *g,
                   const struct drive_create_data *data)
@@ -481,15 +410,12 @@ guestfs_int_drive_protocol_to_string (enum drive_protocol protocol)
   case drive_protocol_file: return "file";
   case drive_protocol_ftp: return "ftp";
   case drive_protocol_ftps: return "ftps";
-  case drive_protocol_gluster: return "gluster";
   case drive_protocol_http: return "http";
   case drive_protocol_https: return "https";
   case drive_protocol_iscsi: return "iscsi";
   case drive_protocol_nbd: return "nbd";
   case drive_protocol_rbd: return "rbd";
-  case drive_protocol_sheepdog: return "sheepdog";
   case drive_protocol_ssh: return "ssh";
-  case drive_protocol_tftp: return "tftp";
   }
   abort ();
 }
@@ -850,10 +776,6 @@ guestfs_impl_add_drive_opts (guestfs_h *g, const char *filename,
     data.protocol = drive_protocol_ftps;
     drv = create_drive_curl (g, &data);
   }
-  else if (STREQ (protocol, "gluster")) {
-    data.protocol = drive_protocol_gluster;
-    drv = create_drive_gluster (g, &data);
-  }
   else if (STREQ (protocol, "http")) {
     data.protocol = drive_protocol_http;
     drv = create_drive_curl (g, &data);
@@ -874,18 +796,10 @@ guestfs_impl_add_drive_opts (guestfs_h *g, const char *filename,
     data.protocol = drive_protocol_rbd;
     drv = create_drive_rbd (g, &data);
   }
-  else if (STREQ (protocol, "sheepdog")) {
-    data.protocol = drive_protocol_sheepdog;
-    drv = create_drive_sheepdog (g, &data);
-  }
   else if (STREQ (protocol, "ssh")) {
     data.protocol = drive_protocol_ssh;
     drv = create_drive_ssh (g, &data);
   }
-  else if (STREQ (protocol, "tftp")) {
-    data.protocol = drive_protocol_tftp;
-    drv = create_drive_curl (g, &data);
-  }
   else {
     error (g, _("unknown protocol ‘%s’"), protocol);
     drv = NULL; /*FALLTHROUGH*/
