@@ -138,6 +138,8 @@ guestfs_impl_inspect_get_icon (guestfs_h *g, const char *root, size_t *size_r,
     else if (STREQ (distro, "rhel") ||
              STREQ (distro, "redhat-based") ||
              STREQ (distro, "centos") ||
+             STREQ (distro, "circle") ||
+             STREQ (distro, "rocky") ||
              STREQ (distro, "scientificlinux") ||
              STREQ (distro, "oraclelinux")) {
       r = icon_rhel (g, guestfs_inspect_get_major_version (g, root), &size);
