@@ -22,9 +22,10 @@
 # to the disk, then instructing btrfs to move the data between
 # devices.
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 skip_unless_feature_available btrfs
 
