@@ -17,9 +17,10 @@
 
 # Test the disk-create API.
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 rm -f disk*.img file:*.img
