@@ -1,5 +1,5 @@
 #!/bin/bash
-# Copyright (C) 2012-2023 Red Hat Inc.
+# Copyright (C) 2012-2025 Red Hat Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,9 +18,10 @@
 # The significance of 27 is that it's the minimum number of disks
 # supported by every known backend in every supported configuration.
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 disks/test-add-disks -n 27
