@@ -1,5 +1,5 @@
 #!/bin/bash
-# Copyright (C) 2013-2023 Red Hat Inc.
+# Copyright (C) 2013-2025 Red Hat Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
 
 # Test that disks map to the correct qemu -drive parameter.
 
+source ./functions.sh
 set -e
 set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 skip_unless_libvirt_minimum_version 1 1 3
 
