@@ -18,9 +18,10 @@
 
 # Test guestfish list-md-devices command
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 output=$(
