@@ -18,9 +18,10 @@
 
 # Test the ntfscat-i command.
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 skip_unless_feature_available ntfs3g
 skip_unless_phony_guest windows.img
