@@ -18,9 +18,10 @@
 
 # Test if we can handle qemu death in the middle of a command.
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 skip_unless_backend direct
 
