@@ -20,9 +20,10 @@
 # https://bugzilla.redhat.com/show_bug.cgi?id=1091803
 # tar-in API didn't cancel the receive correctly along all error paths.
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 guestfish <<EOF
