@@ -20,8 +20,11 @@
 # available space.
 # https://bugzilla.redhat.com/show_bug.cgi?id=580246
 
+source ./functions.sh
 set -e
-export LANG=C
+set -x
+
+skip_if_skipped
 
 rm -f rhbz580246.img rhbz580246.tar
 
@@ -30,7 +33,7 @@ tar cf rhbz580246.tar rhbz580246.img
 
 output=$(
 guestfish 2>&1 <<'EOF'
-add rhbz580246.img
+add rhbz580246.img format:raw
 run
 mkfs ext2 /dev/sda
 mount /dev/sda /
