@@ -19,9 +19,10 @@
 # https://bugzilla.redhat.com/show_bug.cgi?id=602997
 # Fix part-get-bootable to work with missing/unordered partitions.
 
+source ./functions.sh
 set -e
+set -x
 
-$TEST_FUNCTIONS
 skip_if_skipped
 
 output=rhbz602997.output
