@@ -19,12 +19,18 @@
 # https://bugzilla.redhat.com/show_bug.cgi?id=789960
 # Test the mount command error paths.
 
+source ./functions.sh
 set -e
-export LANG=C
+set -x
+
+skip_if_skipped
+skip_unless_phony_guest fedora.img
 
 rm -f rhbz789960.out
 
-guestfish --format=raw -a ../../test-data/phony-guests/fedora.img --ro > rhbz789960.out <<EOF
+guestfish \
+    --format=raw -a $top_builddir/test-data/phony-guests/fedora.img \
+    --ro > rhbz789960.out <<EOF
 run
 
 # Not a device at all, should fail.
