@@ -20,8 +20,11 @@
 # https://bugzilla.redhat.com/show_bug.cgi?id=957772
 # Ensure that tar-out and base64-out commands properly quote arguments.
 
+source ./functions.sh
 set -e
-export LANG=C
+set -x
+
+skip_if_skipped
 
 guestfish -N rhbz957772.img=fs -m /dev/sda1 <<EOF
 mkdir "/test 1"
